You are viewing a plain text version of this content. The canonical link for it is here.
Posted to scm@geronimo.apache.org by dj...@apache.org on 2010/06/24 20:06:33 UTC

svn commit: r957655 [4/15] - in /geronimo/server/trunk: ./ framework/configs/geronimo-gbean-deployer-bootstrap/src/main/history/ framework/configs/geronimo-gbean-deployer/src/main/history/ framework/configs/jsr88-cli/src/main/history/ framework/configs...

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/EJBAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/EJBAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/EJBAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/EJBAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -21,6 +21,7 @@ import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
 
 import javax.ejb.EJB;
@@ -29,15 +30,11 @@ import javax.ejb.EJBLocalHome;
 import javax.ejb.EJBs;
 import javax.ejb.Local;
 import javax.ejb.Remote;
-import org.apache.geronimo.xbeans.javaee6.DescriptionType;
-import org.apache.geronimo.xbeans.javaee6.EjbLinkType;
-import org.apache.geronimo.xbeans.javaee6.EjbLocalRefType;
-import org.apache.geronimo.xbeans.javaee6.EjbRefNameType;
-import org.apache.geronimo.xbeans.javaee6.EjbRefType;
-import org.apache.geronimo.xbeans.javaee6.InjectionTargetType;
-import org.apache.geronimo.xbeans.javaee6.LocalType;
-import org.apache.geronimo.xbeans.javaee6.RemoteType;
-import org.apache.geronimo.xbeans.javaee6.XsdStringType;
+import org.apache.openejb.jee.EjbLocalRef;
+import org.apache.openejb.jee.EjbRef;
+import org.apache.openejb.jee.InjectionTarget;
+import org.apache.openejb.jee.JndiConsumer;
+import org.apache.openejb.jee.Text;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -97,7 +94,7 @@ public final class EJBAnnotationHelper e
      * @return Updated deployment descriptor
      * @throws Exception if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws Exception {
+    public static void processAnnotations(JndiConsumer annotatedApp, AbstractFinder classFinder) throws Exception {
         if (annotatedApp != null) {
             processEJBs(annotatedApp, classFinder);
             processEJB(annotatedApp, classFinder);
@@ -112,7 +109,7 @@ public final class EJBAnnotationHelper e
      * @param classFinder
      * @throws Exception
      */
-    private static void processEJB(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws Exception {
+    private static void processEJB(JndiConsumer annotatedApp, AbstractFinder classFinder) throws Exception {
         log.debug("processEJB(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Class> classesWithEJB = classFinder.findAnnotatedClasses(EJB.class);
@@ -144,7 +141,7 @@ public final class EJBAnnotationHelper e
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processEJB(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -157,7 +154,7 @@ public final class EJBAnnotationHelper e
      * @param classFinder
      * @throws Exception
      */
-    private static void processEJBs(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws Exception {
+    private static void processEJBs(JndiConsumer annotatedApp, AbstractFinder classFinder) throws Exception {
         log.debug("processEJBs(): Entry");
 
         List<Class> classesWithEJBs = classFinder.findAnnotatedClasses(EJBs.class);
@@ -202,7 +199,7 @@ public final class EJBAnnotationHelper e
      * @param method       Method name with the @EJB annoation
      * @param field        Field name with the @EJB annoation
      */
-    private static void addEJB(AnnotatedApp annotatedApp, EJB annotation, Class cls, Method method, Field field) {
+    private static void addEJB(JndiConsumer annotatedApp, EJB annotation, Class cls, Method method, Field field) {
         log.debug("addEJB( [annotatedApp] " + annotatedApp.toString() + "," + '\n' +
                 "[annotation] " + annotation.toString() + "," + '\n' +
                 "[cls] " + (cls != null ? cls.getName() : null) + "," + '\n' +
@@ -263,11 +260,11 @@ public final class EJBAnnotationHelper e
 
             String localRefName = getName(annotation.name(), method, field);
 
-            EjbLocalRefType ejbLocalRef = null;
+            EjbLocalRef ejbLocalRef = null;
             
-            EjbLocalRefType[] ejbLocalRefEntries = annotatedApp.getEjbLocalRefArray();
-            for (EjbLocalRefType ejbLocalRefEntry : ejbLocalRefEntries) {
-                if (ejbLocalRefEntry.getEjbRefName().getStringValue().trim().equals(localRefName)) {
+            Collection<EjbLocalRef> ejbLocalRefEntries = annotatedApp.getEjbLocalRef();
+            for (EjbLocalRef ejbLocalRefEntry : ejbLocalRefEntries) {
+                if (ejbLocalRefEntry.getEjbRefName().trim().equals(localRefName)) {
                     ejbLocalRef = ejbLocalRefEntry;
                     break;
                 }
@@ -278,16 +275,14 @@ public final class EJBAnnotationHelper e
                     log.debug("addEJB(): Does not exist in DD: " + localRefName);
 
                     // Doesn't exist in deployment descriptor -- add new
-                    ejbLocalRef = annotatedApp.addNewEjbLocalRef();
+                    ejbLocalRef = new EjbLocalRef();
 
                     //------------------------------------------------------------------------------
                     // <ejb-local-ref> required elements:
                     //------------------------------------------------------------------------------
 
                     // ejb-ref-name
-                    EjbRefNameType ejbRefName = ejbLocalRef.addNewEjbRefName();
-                    ejbRefName.setStringValue(localRefName);
-                    ejbLocalRef.setEjbRefName(ejbRefName);
+                    ejbLocalRef.setEjbRefName(localRefName);
 
                     //------------------------------------------------------------------------------
                     // <ejb-local-ref> optional elements:
@@ -296,35 +291,29 @@ public final class EJBAnnotationHelper e
                     // local
                     if (interfce != null) {
                         String localAnnotation = interfce.getName();
-                        if (!localAnnotation.equals("")) {
-                            LocalType local = ejbLocalRef.addNewLocal();
-                            local.setStringValue(localAnnotation);
-                            ejbLocalRef.setLocal(local);
+                        if (!localAnnotation.isEmpty()) {
+                            ejbLocalRef.setLocal(localAnnotation);
                         }
                     }
 
                     // ejb-link
                     String beanName = annotation.beanName();
-                    if (!beanName.equals("")) {
-                        EjbLinkType ejbLink = ejbLocalRef.addNewEjbLink();
-                        ejbLink.setStringValue(beanName);
-                        ejbLocalRef.setEjbLink(ejbLink);
+                    if (!beanName.isEmpty()) {
+                        ejbLocalRef.setEjbLink(beanName);
                     }
 
                     // mappedName
                     String mappdedNameAnnotation = annotation.mappedName();
-                    if (!mappdedNameAnnotation.equals("")) {
-                        XsdStringType mappedName = ejbLocalRef.addNewMappedName();
-                        mappedName.setStringValue(mappdedNameAnnotation);
-                        ejbLocalRef.setMappedName(mappedName);
+                    if (!mappdedNameAnnotation.isEmpty()) {
+                        ejbLocalRef.setMappedName(mappdedNameAnnotation);
                     }
 
                     // description
                     String descriptionAnnotation = annotation.description();
-                    if (!descriptionAnnotation.equals("")) {
-                        DescriptionType description = ejbLocalRef.addNewDescription();
-                        description.setStringValue(descriptionAnnotation);
+                    if (!descriptionAnnotation.isEmpty()) {
+                        ejbLocalRef.setDescriptions(new Text[] {new Text(null, descriptionAnnotation)});
                     }
+                    annotatedApp.getEjbLocalRef().add(ejbLocalRef);
                 }
                 catch (Exception e) {
                     log.debug("EJBAnnotationHelper: Exception caught while processing <ejb-local-ref>", e);
@@ -333,9 +322,9 @@ public final class EJBAnnotationHelper e
             
             // injectionTarget
             if (method != null || field != null) {
-                InjectionTargetType[] targets = ejbLocalRef.getInjectionTargetArray();
+                List<InjectionTarget> targets = ejbLocalRef.getInjectionTarget();
                 if (!hasTarget(method, field, targets)) {
-                    configureInjectionTarget(ejbLocalRef.addNewInjectionTarget(), method, field);
+                    ejbLocalRef.getInjectionTarget().add(configureInjectionTarget(method, field));
                 }
             }
         }                                                                           // end if local
@@ -349,11 +338,11 @@ public final class EJBAnnotationHelper e
 
             String remoteRefName = getName(annotation.name(), method, field);
 
-            EjbRefType ejbRef = null;
+            EjbRef ejbRef = null;
 
-            EjbRefType[] ejbRefEntries = annotatedApp.getEjbRefArray();
-            for (EjbRefType ejbRefEntry : ejbRefEntries) {
-                if (ejbRefEntry.getEjbRefName().getStringValue().trim().equals(remoteRefName)) {
+            Collection<EjbRef> ejbRefEntries = annotatedApp.getEjbRef();
+            for (EjbRef ejbRefEntry : ejbRefEntries) {
+                if (ejbRefEntry.getEjbRefName().trim().equals(remoteRefName)) {
                     ejbRef = ejbRefEntry;
                     break;
                 }
@@ -364,16 +353,14 @@ public final class EJBAnnotationHelper e
                     log.debug("addEJB(): Does not exist in DD: " + remoteRefName);
 
                     // Doesn't exist in deployment descriptor -- add new
-                    ejbRef = annotatedApp.addNewEjbRef();
+                    ejbRef = new EjbRef();
 
                     //------------------------------------------------------------------------------
                     // <ejb-ref> required elements:
                     //------------------------------------------------------------------------------
 
                     // ejb-ref-name
-                    EjbRefNameType ejbRefName = ejbRef.addNewEjbRefName();
-                    ejbRefName.setStringValue(remoteRefName);
-                    ejbRef.setEjbRefName(ejbRefName);
+                    ejbRef.setEjbRefName(remoteRefName);
 
                     //------------------------------------------------------------------------------
                     // <ejb-ref> optional elements:
@@ -382,35 +369,29 @@ public final class EJBAnnotationHelper e
                     // remote
                     if (interfce != null) {
                         String remoteAnnotation = interfce.getName();
-                        if (!remoteAnnotation.equals("")) {
-                            RemoteType remote = ejbRef.addNewRemote();
-                            remote.setStringValue(remoteAnnotation);
-                            ejbRef.setRemote(remote);
+                        if (!remoteAnnotation.isEmpty()) {
+                            ejbRef.setRemote(remoteAnnotation);
                         }
                     }
 
                     // ejb-link
                     String beanName = annotation.beanName();
-                    if (!beanName.equals("")) {
-                        EjbLinkType ejbLink = ejbRef.addNewEjbLink();
-                        ejbLink.setStringValue(beanName);
-                        ejbRef.setEjbLink(ejbLink);
+                    if (!beanName.isEmpty()) {
+                        ejbRef.setEjbLink(beanName);
                     }
 
                     // mappedName
                     String mappdedNameAnnotation = annotation.mappedName();
-                    if (!mappdedNameAnnotation.equals("")) {
-                        XsdStringType mappedName = ejbRef.addNewMappedName();
-                        mappedName.setStringValue(mappdedNameAnnotation);
-                        ejbRef.setMappedName(mappedName);
+                    if (!mappdedNameAnnotation.isEmpty()) {
+                        ejbRef.setMappedName(mappdedNameAnnotation);
                     }
 
                     // description
                     String descriptionAnnotation = annotation.description();
-                    if (!descriptionAnnotation.equals("")) {
-                        DescriptionType description = ejbRef.addNewDescription();
-                        description.setStringValue(descriptionAnnotation);
+                    if (!descriptionAnnotation.isEmpty()) {
+                        ejbRef.setDescriptions(new Text[] {new Text(null, descriptionAnnotation) });
                     }
+                    annotatedApp.getEjbRef().add(ejbRef);
                 }
                 catch (Exception e) {
                     log.debug("EJBAnnotationHelper: Exception caught while processing <ejb-ref>", e);
@@ -419,9 +400,9 @@ public final class EJBAnnotationHelper e
             
             // injectionTarget
             if (method != null || field != null) {
-                InjectionTargetType[] targets = ejbRef.getInjectionTargetArray();
+                List<InjectionTarget> targets = ejbRef.getInjectionTarget();
                 if (!hasTarget(method, field, targets)) {
-                    configureInjectionTarget(ejbRef.addNewInjectionTarget(), method, field);
+                    ejbRef.getInjectionTarget().add(configureInjectionTarget(method, field));
                 }
             }
         }                                                                           // end if remote
@@ -434,11 +415,11 @@ public final class EJBAnnotationHelper e
 
             String remoteRefName = getName(annotation.name(), method, field);
 
-            EjbRefType ejbRef = null;
+            EjbRef ejbRef = null;
 
-            EjbRefType[] ejbRefEntries = annotatedApp.getEjbRefArray();
-            for (EjbRefType ejbRefEntry : ejbRefEntries) {
-                if (ejbRefEntry.getEjbRefName().getStringValue().trim().equals(remoteRefName)) {
+            Collection<EjbRef> ejbRefEntries = annotatedApp.getEjbRef();
+            for (EjbRef ejbRefEntry : ejbRefEntries) {
+                if (ejbRefEntry.getEjbRefName().trim().equals(remoteRefName)) {
                     ejbRef = ejbRefEntry;
                     break;
                 }
@@ -450,17 +431,16 @@ public final class EJBAnnotationHelper e
 
                     // Doesn't exist in deployment descriptor -- add as an <ejb-ref> to the
                     // ambiguous list so that it can be resolved later
-                    ejbRef = EjbRefType.Factory.newInstance();
-                    annotatedApp.getAmbiguousEjbRefs().add(ejbRef);
+                    ejbRef = new EjbRef();
+                    //TODO how to deal with this?
+//                    annotatedApp.getAmbiguousEjbRefs().add(ejbRef);
 
                     //------------------------------------------------------------------------------
                     // <ejb-ref> required elements:
                     //------------------------------------------------------------------------------
 
                     // ejb-ref-name
-                    EjbRefNameType ejbRefName = ejbRef.addNewEjbRefName();
-                    ejbRefName.setStringValue(remoteRefName);
-                    ejbRef.setEjbRefName(ejbRefName);
+                    ejbRef.setEjbRefName(remoteRefName);
 
                     //------------------------------------------------------------------------------
                     // <ejb-ref> optional elements:
@@ -469,34 +449,27 @@ public final class EJBAnnotationHelper e
                     // remote
                     if (interfce != null) {
                         String remoteAnnotation = interfce.getName();
-                        if (!remoteAnnotation.equals("")) {
-                            RemoteType remote = ejbRef.addNewRemote();
-                            remote.setStringValue(remoteAnnotation);
-                            ejbRef.setRemote(remote);
+                        if (!remoteAnnotation.isEmpty()) {
+                            ejbRef.setRemote(remoteAnnotation);
                         }
                     }
 
                     // ejb-link
                     String beanName = annotation.beanName();
-                    if (!beanName.equals("")) {
-                        EjbLinkType ejbLink = ejbRef.addNewEjbLink();
-                        ejbLink.setStringValue(beanName);
-                        ejbRef.setEjbLink(ejbLink);
+                    if (!beanName.isEmpty()) {
+                        ejbRef.setEjbLink(beanName);
                     }
 
                     // mappedName
                     String mappdedNameAnnotation = annotation.mappedName();
-                    if (!mappdedNameAnnotation.equals("")) {
-                        XsdStringType mappedName = ejbRef.addNewMappedName();
-                        mappedName.setStringValue(mappdedNameAnnotation);
-                        ejbRef.setMappedName(mappedName);
+                    if (!mappdedNameAnnotation.isEmpty()) {
+                        ejbRef.setMappedName(mappdedNameAnnotation);
                     }
 
                     // description
                     String descriptionAnnotation = annotation.description();
-                    if (!descriptionAnnotation.equals("")) {
-                        DescriptionType description = ejbRef.addNewDescription();
-                        description.setStringValue(descriptionAnnotation);
+                    if (!descriptionAnnotation.isEmpty()) {
+                        ejbRef.setDescriptions(new Text[] {new Text(null, descriptionAnnotation) });
                     }
                 }
                 catch (Exception e) {
@@ -506,9 +479,9 @@ public final class EJBAnnotationHelper e
             
             // injectionTarget
             if (method != null || field != null) {
-                InjectionTargetType[] targets = ejbRef.getInjectionTargetArray();
+                List<InjectionTarget> targets = ejbRef.getInjectionTarget();
                 if (!hasTarget(method, field, targets)) {
-                    configureInjectionTarget(ejbRef.addNewInjectionTarget(), method, field);
+                    ejbRef.getInjectionTarget().add(configureInjectionTarget(method, field));
                 }
             }
 

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/HandlerChainAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/HandlerChainAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/HandlerChainAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/HandlerChainAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -17,27 +17,22 @@
 
 package org.apache.geronimo.j2ee.deployment.annotation;
 
+import java.io.InputStream;
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.net.MalformedURLException;
 import java.net.URL;
+import java.util.Collection;
 import java.util.List;
 
 import javax.jws.HandlerChain;
 import javax.xml.ws.WebServiceRef;
 import org.apache.geronimo.common.DeploymentException;
-import org.apache.geronimo.deployment.xmlbeans.XmlBeansUtil;
-import org.apache.geronimo.xbeans.javaee.HandlerChainsDocument;
-import org.apache.geronimo.xbeans.javaee.PortComponentHandlerType;
-import org.apache.geronimo.xbeans.javaee6.DescriptionType;
-import org.apache.geronimo.xbeans.javaee6.HandlerChainType;
-import org.apache.geronimo.xbeans.javaee6.HandlerChainsType;
-import org.apache.geronimo.xbeans.javaee6.HandlerType;
-import org.apache.geronimo.xbeans.javaee6.ParamValueType;
-import org.apache.geronimo.xbeans.javaee6.ServiceRefType;
-import org.apache.geronimo.xbeans.javaee6.XsdQNameType;
+import org.apache.openejb.jee.HandlerChains;
+import org.apache.openejb.jee.JaxbJavaee;
+import org.apache.openejb.jee.JndiConsumer;
+import org.apache.openejb.jee.ServiceRef;
 import org.apache.xbean.finder.AbstractFinder;
-import org.apache.xmlbeans.XmlObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -80,7 +75,7 @@ public final class HandlerChainAnnotatio
      * @param classFinder ClassFinder containing classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    public static void processAnnotations(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         if ( annotatedApp != null && classFinder.isAnnotationPresent(HandlerChain.class)) {
             processHandlerChain(annotatedApp, classFinder);
         }
@@ -94,7 +89,7 @@ public final class HandlerChainAnnotatio
      * @param classFinder ClassFinder containing classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processHandlerChain(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processHandlerChain(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processHandlerChain(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Method> methodswithHandlerChain = classFinder.findAnnotatedMethods(HandlerChain.class);
@@ -118,7 +113,7 @@ public final class HandlerChainAnnotatio
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processHandlerChain(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -146,7 +141,7 @@ public final class HandlerChainAnnotatio
      * @param method     Method name with the @HandlerChain annotation
      * @param field      Field name with the @HandlerChain annotation
      */
-    private static void addHandlerChain(AnnotatedApp annotatedApp, final HandlerChain annotation, Class cls, Method method, Field field) {
+    private static void addHandlerChain(JndiConsumer annotatedApp, final HandlerChain annotation, Class cls, Method method, Field field) {
         log.debug("addHandlerChain( [annotatedApp] " + annotatedApp.toString() + "," + '\n' +
                 "[annotation] " + annotation.toString() + "," + '\n' +
                 "[cls] " + (cls != null ? cls.getName() : null) + "," + '\n' +
@@ -208,10 +203,10 @@ public final class HandlerChainAnnotatio
 
                 if (url != null) {
                     // Find the <service-ref> entry this handler chain belongs to and insert it
-                    ServiceRefType[] serviceRefs = annotatedApp.getServiceRefArray();
+                    Collection<ServiceRef> serviceRefs = annotatedApp.getServiceRef();
                     boolean exists = false;
-                    for ( ServiceRefType serviceRef : serviceRefs ) {
-                        if ( serviceRef.getServiceRefName().getStringValue().trim().equals(serviceRefName) && !serviceRef.isSetHandlerChains()) {
+                    for ( ServiceRef serviceRef : serviceRefs ) {
+                        if ( serviceRef.getServiceRefName().trim().equals(serviceRefName) && serviceRef.getHandlerChains() == null) {
                             insertHandlers(serviceRef, url);
                             exists = true;
                             break;
@@ -252,7 +247,7 @@ public final class HandlerChainAnnotatio
         return url;
     }
     
-    public static void insertHandlers(ServiceRefType serviceRef, HandlerChain annotation, Class clazz) {
+    public static void insertHandlers(ServiceRef serviceRef, HandlerChain annotation, Class clazz) {
         String handlerChainFile = annotation.file();
         log.debug("handlerChainFile: " + handlerChainFile);
         if (handlerChainFile == null || handlerChainFile.trim().length() == 0) {
@@ -275,69 +270,16 @@ public final class HandlerChainAnnotatio
         }
     }
     
-    public static void insertHandlers(ServiceRefType serviceRef, URL url) throws Exception {
-        // Bind the XML handler chain file to an XMLBeans document
-        XmlObject xml = XmlBeansUtil.parse(url, null);
-        HandlerChainsDocument hcd = (HandlerChainsDocument) XmlBeansUtil.typedCopy(xml, HandlerChainsDocument.type);
-        org.apache.geronimo.xbeans.javaee.HandlerChainsType handlerChains = hcd.getHandlerChains();
-
-        HandlerChainsType  serviceRefHandlerChains = serviceRef.addNewHandlerChains();
-        for (org.apache.geronimo.xbeans.javaee.HandlerChainType handlerChain : handlerChains.getHandlerChainArray()) {
-            HandlerChainType serviceRefHandlerChain = serviceRefHandlerChains.addNewHandlerChain();
-            if (handlerChain.getPortNamePattern() != null) {
-                serviceRefHandlerChain.setPortNamePattern(handlerChain.getPortNamePattern());
-            }
-            if (handlerChain.getServiceNamePattern() != null) {
-                serviceRefHandlerChain.setServiceNamePattern(handlerChain.getServiceNamePattern());
-            }
-            if (handlerChain.getProtocolBindings() != null) {
-                serviceRefHandlerChain.setProtocolBindings(handlerChain.getProtocolBindings());
-            }
-            for (PortComponentHandlerType srcHandler : handlerChain.getHandlerArray()) {
-                HandlerType serviceRefHandler = serviceRefHandlerChain.addNewHandler();
-                serviceRefHandler.setId(srcHandler.getId());
-                //Copy HandlerName
-                org.apache.geronimo.xbeans.javaee.String srcHandlerName = srcHandler.getHandlerName();
-                org.apache.geronimo.xbeans.javaee6.String desHandlerName = serviceRefHandler.addNewHandlerName();
-                desHandlerName.setStringValue(srcHandlerName.getStringValue());
-                desHandlerName.setId(srcHandlerName.getId());
-                //Copy HandlerClass
-                org.apache.geronimo.xbeans.javaee.String srcHandlerClass = srcHandler.getHandlerClass();
-                org.apache.geronimo.xbeans.javaee6.String desHandlerClass = serviceRefHandler.addNewHandlerClass();
-                desHandlerClass.setId(srcHandlerClass.getId());
-                desHandlerClass.setStringValue(srcHandlerClass.getStringValue());
-                //Copy DescriptionArray
-                for (org.apache.geronimo.xbeans.javaee.DescriptionType srcDescription : srcHandler.getDescriptionArray()) {
-                    DescriptionType desDescription = serviceRefHandler.addNewDescription();
-                    desDescription.setStringValue(srcDescription.getStringValue());
-                    desDescription.setId(srcDescription.getId());
-                }
-                //Copy InitParamArray
-                for (org.apache.geronimo.xbeans.javaee.ParamValueType srcParamValue : srcHandler.getInitParamArray()) {
-                    ParamValueType desParamValue = serviceRefHandler.addNewInitParam();
-                    srcParamValue.setId(desParamValue.getId());
-                    desParamValue.addNewParamName().setStringValue(srcParamValue.getParamName().getStringValue());
-                    desParamValue.addNewParamValue().setStringValue(srcParamValue.getParamValue().getStringValue());
-                    for (org.apache.geronimo.xbeans.javaee.DescriptionType srcDescription : srcParamValue.getDescriptionArray()) {
-                        DescriptionType desDescription = desParamValue.addNewDescription();
-                        desDescription.setId(srcDescription.getId());
-                        desDescription.setStringValue(srcDescription.getStringValue());
-                    }
-                }
-                //Copy SoapHeaderArray
-                for (org.apache.geronimo.xbeans.javaee.XsdQNameType srcSOAPHeader : srcHandler.getSoapHeaderArray()) {
-                    XsdQNameType desSOAPHeader = serviceRefHandler.addNewSoapHeader();
-                    desSOAPHeader.setId(srcSOAPHeader.getId());
-                    desSOAPHeader.setQNameValue(srcSOAPHeader.getQNameValue());
-                }
-                //Copy SoapRoleArray
-                for (org.apache.geronimo.xbeans.javaee.String srcSOAPRole : srcHandler.getSoapRoleArray()) {
-                    org.apache.geronimo.xbeans.javaee6.String desSOAPRole = serviceRefHandler.addNewSoapRole();
-                    desSOAPRole.setId(srcSOAPRole.getId());
-                    desSOAPRole.setStringValue(srcSOAPRole.getStringValue());
-                }
-            }
+    public static void insertHandlers(ServiceRef serviceRef, URL url) throws Exception {
+        HandlerChains handlerChains;
+        InputStream in = url.openStream();
+        try {
+            handlerChains = (HandlerChains) JaxbJavaee.unmarshal(HandlerChains.class, in);
+         } finally {
+            in.close();
         }
+
+        serviceRef.setHandlerChains(handlerChains);
     }
 
 }

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceContextAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceContextAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceContextAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceContextAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -21,6 +21,7 @@ import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
 
 import javax.persistence.PersistenceContext;
@@ -28,12 +29,10 @@ import javax.persistence.PersistenceCont
 import javax.persistence.PersistenceContexts;
 import javax.persistence.PersistenceProperty;
 import org.apache.geronimo.common.DeploymentException;
-import org.apache.geronimo.xbeans.javaee6.InjectionTargetType;
-import org.apache.geronimo.xbeans.javaee6.JndiNameType;
-import org.apache.geronimo.xbeans.javaee6.PersistenceContextRefType;
-import org.apache.geronimo.xbeans.javaee6.PersistenceContextTypeType;
-import org.apache.geronimo.xbeans.javaee6.PropertyType;
-import org.apache.geronimo.xbeans.javaee6.XsdStringType;
+import org.apache.openejb.jee.InjectionTarget;
+import org.apache.openejb.jee.JndiConsumer;
+import org.apache.openejb.jee.PersistenceContextRef;
+import org.apache.openejb.jee.Property;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -81,7 +80,7 @@ public final class PersistenceContextAnn
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    public static void processAnnotations(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         if (annotatedApp != null) {
             if (classFinder.isAnnotationPresent(PersistenceContexts.class)) {
                 processPersistenceContexts(annotatedApp, classFinder);
@@ -100,7 +99,7 @@ public final class PersistenceContextAnn
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processPersistenceContext(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processPersistenceContext(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processPersistenceContext(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Class> classeswithPersistenceContext = classFinder.findAnnotatedClasses(PersistenceContext.class);
@@ -132,7 +131,7 @@ public final class PersistenceContextAnn
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processPersistenceContext(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -145,7 +144,7 @@ public final class PersistenceContextAnn
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processPersistenceContexts(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processPersistenceContexts(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processPersistenceContexts(): Entry");
 
         List<Class> classeswithPersistenceContexts = classFinder.findAnnotatedClasses(PersistenceContexts.class);
@@ -188,7 +187,7 @@ public final class PersistenceContextAnn
      * @param field      Field name with the @PersistenceContext annoation
      * @param annotatedApp  Access to the specc dd
      */
-    private static void addPersistenceContext(AnnotatedApp annotatedApp, PersistenceContext annotation, Class cls, Method method, Field field) {
+    private static void addPersistenceContext(JndiConsumer annotatedApp, PersistenceContext annotation, Class cls, Method method, Field field) {
         log.debug("addPersistenceContext( [annotatedApp] " + annotatedApp.toString() + "," + '\n' +
                 "[annotation] " + annotation.toString() + "," + '\n' +
                 "[cls] " + (cls != null ? cls.getName() : null) + "," + '\n' +
@@ -209,13 +208,13 @@ public final class PersistenceContextAnn
         log.debug("addPersistenceContext(): PersistenceContextRefName: " + persistenceContextRefName);
 
         // If there is already xml for the persistence context ref, just add injection targets and return.
-        PersistenceContextRefType[] persistenceContextRefs = annotatedApp.getPersistenceContextRefArray();
-        for (PersistenceContextRefType persistenceContextRef : persistenceContextRefs) {
-            if (persistenceContextRef.getPersistenceContextRefName().getStringValue().trim().equals(persistenceContextRefName)) {
+        Collection<PersistenceContextRef> persistenceContextRefs = annotatedApp.getPersistenceContextRef();
+        for (PersistenceContextRef persistenceContextRef : persistenceContextRefs) {
+            if (persistenceContextRef.getPersistenceContextRefName().trim().equals(persistenceContextRefName)) {
                 if (method != null || field != null) {
-                    InjectionTargetType[] targets = persistenceContextRef.getInjectionTargetArray();
+                    List<InjectionTarget> targets = persistenceContextRef.getInjectionTarget();
                     if (!hasTarget(method, field, targets)) {
-                        configureInjectionTarget(persistenceContextRef.addNewInjectionTarget(), method, field);
+                        persistenceContextRef.getInjectionTarget().add(configureInjectionTarget(method, field));
                     }
                 }
                 return;
@@ -223,15 +222,14 @@ public final class PersistenceContextAnn
         }
 
         // Doesn't exist in deployment descriptor -- add new
-        PersistenceContextRefType persistenceContextRef = annotatedApp.addNewPersistenceContextRef();
+        PersistenceContextRef persistenceContextRef = new PersistenceContextRef();
 
         //------------------------------------------------------------------------------
         // <persistence-context-ref> required elements:
         //------------------------------------------------------------------------------
 
         // persistence-context-ref-name
-        JndiNameType unitRefName = persistenceContextRef.addNewPersistenceContextRefName();
-        unitRefName.setStringValue(persistenceContextRefName);
+        persistenceContextRef.setPersistenceContextRefName(persistenceContextRefName);
 
         //------------------------------------------------------------------------------
         // <persistence-context-ref> optional elements:
@@ -239,36 +237,31 @@ public final class PersistenceContextAnn
 
         // persistence-unit-name
         String unitNameAnnotation = annotation.unitName();
-        if (!unitNameAnnotation.equals("")) {
-            org.apache.geronimo.xbeans.javaee6.String persistenceUnitName = persistenceContextRef.addNewPersistenceUnitName();
-            persistenceUnitName.setStringValue(unitNameAnnotation);
+        if (!unitNameAnnotation.isEmpty()) {
+            persistenceContextRef.setPersistenceUnitName(unitNameAnnotation);
         }
 
         // persistence-context-type
         if (annotation.type() == PersistenceContextType.TRANSACTION) {
-            PersistenceContextTypeType persistenceContextType = persistenceContextRef.addNewPersistenceContextType();
-            persistenceContextType.setStringValue("Transaction");
-            persistenceContextRef.setPersistenceContextType(persistenceContextType);
+            persistenceContextRef.setPersistenceContextType(org.apache.openejb.jee.PersistenceContextType.TRANSACTION);
         } else if (annotation.type() == PersistenceContextType.EXTENDED) {
-            PersistenceContextTypeType persistenceContextType = persistenceContextRef.addNewPersistenceContextType();
-            persistenceContextType.setStringValue("Extended");
-            persistenceContextRef.setPersistenceContextType(persistenceContextType);
+            persistenceContextRef.setPersistenceContextType(org.apache.openejb.jee.PersistenceContextType.EXTENDED);
         }
 
         // persistence-context-properties
         PersistenceProperty[] properties = annotation.properties();
         for (PersistenceProperty property : properties) {
-            PropertyType propertyType = persistenceContextRef.addNewPersistenceProperty();
-            XsdStringType propertyName = propertyType.addNewName();
-            propertyName.setStringValue(property.name());
-            XsdStringType propertyValue = propertyType.addNewValue();
-            propertyValue.setStringValue(property.value());
+            Property prop = new Property();
+            prop.setName(property.name());
+            prop.setValue(property.value());
+            persistenceContextRef.getPersistenceProperty().add(prop);
         }
 
         // injection targets
         if (method != null || field != null) {
-            configureInjectionTarget(persistenceContextRef.addNewInjectionTarget(), method, field);
+            persistenceContextRef.getInjectionTarget().add(configureInjectionTarget(method, field));
         }
+        annotatedApp.getPersistenceContextRef().add(persistenceContextRef);
 
     }
 

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceUnitAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceUnitAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceUnitAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/PersistenceUnitAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -21,14 +21,15 @@ import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
 
 import javax.persistence.PersistenceUnit;
 import javax.persistence.PersistenceUnits;
 import org.apache.geronimo.common.DeploymentException;
-import org.apache.geronimo.xbeans.javaee6.InjectionTargetType;
-import org.apache.geronimo.xbeans.javaee6.JndiNameType;
-import org.apache.geronimo.xbeans.javaee6.PersistenceUnitRefType;
+import org.apache.openejb.jee.InjectionTarget;
+import org.apache.openejb.jee.JndiConsumer;
+import org.apache.openejb.jee.PersistenceUnitRef;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -76,7 +77,7 @@ public final class PersistenceUnitAnnota
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    public static void processAnnotations(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         if (annotatedApp != null) {
             if (classFinder.isAnnotationPresent(PersistenceUnits.class)) {
                 processPersistenceUnits(annotatedApp, classFinder);
@@ -95,7 +96,7 @@ public final class PersistenceUnitAnnota
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processPersistenceUnit(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processPersistenceUnit(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processPersistenceUnit(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Class> classeswithPersistenceUnit = classFinder.findAnnotatedClasses(PersistenceUnit.class);
@@ -127,7 +128,7 @@ public final class PersistenceUnitAnnota
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processPersistenceUnit(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -140,7 +141,7 @@ public final class PersistenceUnitAnnota
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processPersistenceUnits(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processPersistenceUnits(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processPersistenceUnits(): Entry");
 
         List<Class> classeswithPersistenceUnits = classFinder.findAnnotatedClasses(PersistenceUnits.class);
@@ -184,7 +185,7 @@ public final class PersistenceUnitAnnota
      * @param field      Field name with the @PersistenceUnit annoation
      * @param annotatedApp  Access to the specc dd
      */
-    private static void addPersistenceUnit(AnnotatedApp annotatedApp, PersistenceUnit annotation, Class cls, Method method, Field field) {
+    private static void addPersistenceUnit(JndiConsumer annotatedApp, PersistenceUnit annotation, Class cls, Method method, Field field) {
         log.debug("addPersistenceUnit( [annotatedApp] " + annotatedApp.toString() + "," + '\n' +
                 "[annotation] " + annotation.toString() + "," + '\n' +
                 "[cls] " + (cls != null ? cls.getName() : null) + "," + '\n' +
@@ -205,13 +206,13 @@ public final class PersistenceUnitAnnota
         log.debug("addPersistenceUnit(): persistenceUnitRefName: " + persistenceUnitRefName);
 
         // If there is already xml for the persistence unit ref, just add injection targets and return.
-        PersistenceUnitRefType[] persistenceUnitRefs = annotatedApp.getPersistenceUnitRefArray();
-        for (PersistenceUnitRefType persistenceUnitRef : persistenceUnitRefs) {
-            if (persistenceUnitRef.getPersistenceUnitRefName().getStringValue().trim().equals(persistenceUnitRefName)) {
+        Collection<PersistenceUnitRef> persistenceUnitRefs = annotatedApp.getPersistenceUnitRef();
+        for (PersistenceUnitRef persistenceUnitRef : persistenceUnitRefs) {
+            if (persistenceUnitRef.getPersistenceUnitRefName().trim().equals(persistenceUnitRefName)) {
                 if (method != null || field != null) {
-                    InjectionTargetType[] targets = persistenceUnitRef.getInjectionTargetArray();
+                    List<InjectionTarget> targets = persistenceUnitRef.getInjectionTarget();
                     if (!hasTarget(method, field, targets)) {
-                        configureInjectionTarget(persistenceUnitRef.addNewInjectionTarget(), method, field);
+                        persistenceUnitRef.getInjectionTarget().add(configureInjectionTarget(method, field));
                     }
                 }
                 return;
@@ -219,15 +220,14 @@ public final class PersistenceUnitAnnota
         }
 
         // Doesn't exist in deployment descriptor -- add new
-        PersistenceUnitRefType persistenceUnitRef = annotatedApp.addNewPersistenceUnitRef();
+        PersistenceUnitRef persistenceUnitRef = new PersistenceUnitRef();
 
         //------------------------------------------------------------------------------
         // <persistence-unit-ref> required elements:
         //------------------------------------------------------------------------------
 
         // persistence-unit-ref-name
-        JndiNameType unitRefName = persistenceUnitRef.addNewPersistenceUnitRefName();
-        unitRefName.setStringValue(persistenceUnitRefName);
+        persistenceUnitRef.setPersistenceUnitRefName(persistenceUnitRefName);
 
         //------------------------------------------------------------------------------
         // <persistence-unit-ref> optional elements:
@@ -236,15 +236,14 @@ public final class PersistenceUnitAnnota
         // persistence-unit-name
         String unitNameAnnotation = annotation.unitName();
         if (!unitNameAnnotation.equals("")) {
-            org.apache.geronimo.xbeans.javaee6.String persistenceUnitName = persistenceUnitRef.addNewPersistenceUnitName();
-            persistenceUnitName.setStringValue(unitNameAnnotation);
+            persistenceUnitRef.setPersistenceUnitName(unitNameAnnotation);
         }
 
         // injection targets
         if (method != null || field != null) {
-            configureInjectionTarget(persistenceUnitRef.addNewInjectionTarget(), method, field);
+            persistenceUnitRef.getInjectionTarget().add(configureInjectionTarget(method, field));
         }
-
+        annotatedApp.getPersistenceUnitRef().add(persistenceUnitRef);
     }
 
 }

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/ResourceAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/ResourceAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/ResourceAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/ResourceAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -26,6 +26,7 @@ import java.util.List;
 import javax.annotation.Resource;
 import javax.annotation.Resources;
 import org.apache.geronimo.common.DeploymentException;
+import org.apache.openejb.jee.JndiConsumer;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -70,7 +71,7 @@ public final class ResourceAnnotationHel
      * Update the deployment descriptor from Resource and Resources annotations
      * @throws Exception if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
+    public static void processAnnotations(JndiConsumer annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
         if (annotatedApp != null) {
             if (classFinder.isAnnotationPresent(Resources.class)) {
                 processResources(annotatedApp, classFinder, resourceProcessor);
@@ -90,7 +91,7 @@ public final class ResourceAnnotationHel
      * @param resourceProcessor
      * @throws Exception
      */
-    private static void processResource(AnnotatedApp annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
+    private static void processResource(JndiConsumer annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
         log.debug("processResource(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Class> classeswithResource = classFinder.findAnnotatedClasses(Resource.class);
@@ -122,7 +123,7 @@ public final class ResourceAnnotationHel
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processResource(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -136,7 +137,7 @@ public final class ResourceAnnotationHel
      * @param resourceProcessor
      * @throws Exception
      */
-    private static void processResources(AnnotatedApp annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
+    private static void processResources(JndiConsumer annotatedApp, AbstractFinder classFinder, ResourceProcessor resourceProcessor) throws Exception {
         log.debug("processResources(): Entry");
 
         List<Class> classeswithResources = classFinder.findAnnotatedClasses(Resources.class);
@@ -159,7 +160,7 @@ public final class ResourceAnnotationHel
 
     public abstract static class ResourceProcessor extends AnnotationHelper {
 
-        public abstract boolean processResource(AnnotatedApp annotatedApp, Resource annotation, Class cls, Method method, Field field) throws DeploymentException;
+        public abstract boolean processResource(JndiConsumer jndiConsumer, Resource annotation, Class cls, Method method, Field field) throws DeploymentException;
 
         /**
          * Resource name:

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/SecurityAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/SecurityAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/SecurityAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/SecurityAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -23,11 +23,8 @@ import javax.annotation.security.Declare
 import javax.annotation.security.RunAs;
 import javax.servlet.Servlet;
 import org.apache.geronimo.common.DeploymentException;
-import org.apache.geronimo.xbeans.javaee6.RoleNameType;
-import org.apache.geronimo.xbeans.javaee6.RunAsType;
-import org.apache.geronimo.xbeans.javaee6.SecurityRoleType;
-import org.apache.geronimo.xbeans.javaee6.ServletType;
-import org.apache.geronimo.xbeans.javaee6.WebAppType;
+import org.apache.openejb.jee.SecurityRole;
+import org.apache.openejb.jee.WebApp;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -71,7 +68,7 @@ public final class SecurityAnnotationHel
      * @param classFinder  Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    public static void processAnnotations(WebAppType webApp, AbstractFinder classFinder) throws DeploymentException {
+    public static void processAnnotations(WebApp webApp, AbstractFinder classFinder) throws DeploymentException {
         if (webApp != null && classFinder != null) {
             if (classFinder.isAnnotationPresent(DeclareRoles.class)) {
                 processDeclareRoles(webApp, classFinder);
@@ -90,7 +87,7 @@ public final class SecurityAnnotationHel
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processDeclareRoles(WebAppType webApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processDeclareRoles(WebApp webApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processDeclareRoles(): Entry: webApp: " + webApp.toString());
 
         List<Class> classesWithDeclareRoles = classFinder.findAnnotatedClasses(DeclareRoles.class);
@@ -104,7 +101,7 @@ public final class SecurityAnnotationHel
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(new AnnotatedWebApp(webApp));
+//        validateDD(new AnnotatedWebApp(webApp));
 
         log.debug("processDeclareRoles(): Exit: webApp: " + webApp.toString());
     }
@@ -117,7 +114,7 @@ public final class SecurityAnnotationHel
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processRunAs(WebAppType webApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processRunAs(WebApp webApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processRunAs(): Entry: webApp: " + webApp.toString());
 
         List<Class> classesWithRunAs = classFinder.findAnnotatedClasses(RunAs.class);
@@ -131,7 +128,7 @@ public final class SecurityAnnotationHel
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(new AnnotatedWebApp(webApp));
+//        validateDD(new AnnotatedWebApp(webApp));
 
         log.debug("processRunAs(): Exit: webApp: " + webApp.toString());
     }
@@ -156,20 +153,20 @@ public final class SecurityAnnotationHel
      * @param annotation    @DeclareRoles annotation
      * @param cls           Class name with the @DeclareRoles annoation
      */
-    private static void addDeclareRoles(WebAppType webApp, DeclareRoles annotation, Class cls) {
+    private static void addDeclareRoles(WebApp webApp, DeclareRoles annotation, Class cls) {
         log.debug("addDeclareRoles( [webApp] " + webApp.toString() + "," + '\n' +
                   "[annotation] " + annotation.toString() + "," + '\n' +
                   "[cls] " + (cls != null ? cls.getName() : null) + "): Entry");
 
         // Get all the <security-role> tags from the deployment descriptor
-        SecurityRoleType[] securityRoles = webApp.getSecurityRoleArray();
+        List<SecurityRole> securityRoles = webApp.getSecurityRole();
 
         String[] annotationRoleNames = annotation.value();
         for (String annotationRoleName : annotationRoleNames) {
             if (!annotationRoleName.equals("")) {
                 boolean exists = false;
-                for (SecurityRoleType securityRole : securityRoles) {
-                    if (securityRole.getRoleName().getStringValue().trim().equals(annotationRoleName)) {
+                for (SecurityRole securityRole : securityRoles) {
+                    if (securityRole.getRoleName().trim().equals(annotationRoleName)) {
                         exists = true;
                         break;
                     }
@@ -179,9 +176,9 @@ public final class SecurityAnnotationHel
                 }
                 else {
                     log.debug("addDeclareRoles: <security-role> entry NOT found: " + annotationRoleName);
-                    SecurityRoleType securityRole = webApp.addNewSecurityRole();
-                    RoleNameType roleName = securityRole.addNewRoleName();
-                    roleName.setStringValue(annotationRoleName);
+                    SecurityRole securityRole = new SecurityRole();
+                    securityRole.setRoleName(annotationRoleName);
+                    webApp.getSecurityRole().add(securityRole);
                 }
             }
         }
@@ -210,21 +207,21 @@ public final class SecurityAnnotationHel
      * @param annotation    @RunAs annotation
      * @param cls           Class name with the @RunAs annoation
      */
-    private static void addRunAs(WebAppType webApp, RunAs annotation, Class cls) {
+    private static void addRunAs(WebApp webApp, RunAs annotation, Class cls) {
         log.debug("addRunAs( [webApp] " + webApp.toString() + "," + '\n' +
                   "[annotation] " + annotation.toString() + "," + '\n' +
                   "[cls] " + (cls != null ? cls.getName() : null) + "): Entry");
 
         String annotationRunAs = annotation.value();
         if (!annotationRunAs.equals("")) {
-            ServletType[] servlets = webApp.getServletArray();
+            List<org.apache.openejb.jee.Servlet> servlets = webApp.getServlet();
             boolean exists = false;
-            for (ServletType servlet : servlets) {
-                if (servlet.getServletClass().getStringValue().trim().equals(cls.getName())) {
-                    if (!servlet.isSetRunAs()) {
-                        RunAsType runAsType = servlet.addNewRunAs();
-                        RoleNameType roleName = runAsType.addNewRoleName();
-                        roleName.setStringValue(annotationRunAs);
+            for (org.apache.openejb.jee.Servlet servlet : servlets) {
+                if (servlet.getServletClass().trim().equals(cls.getName())) {
+                    if (servlet.getRunAs() == null) {
+                        org.apache.openejb.jee.RunAs runAs = new org.apache.openejb.jee.RunAs();
+                        runAs.setRoleName(annotationRunAs);
+                        servlet.setRunAs(runAs);
                     }
                     exists = true;
                     break;

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/WebServiceRefAnnotationHelper.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/WebServiceRefAnnotationHelper.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13NakedTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13NakedTest.java Thu Jun 24 18:06:24 2010
@@ -34,10 +34,10 @@ public class EARConfigBuilder13NakedTest
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.3-naked.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13Test.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13Test.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13Test.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13Test.java Thu Jun 24 18:06:24 2010
@@ -16,10 +16,8 @@
  */
 package org.apache.geronimo.j2ee.deployment;
 
-import java.util.Map;
 import java.util.jar.JarFile;
 
-import org.apache.geronimo.j2ee.jndi.JndiKey;
 import org.apache.geronimo.kernel.repository.Artifact;
 import org.apache.geronimo.kernel.util.JarUtils;
 
@@ -37,10 +35,10 @@ public class EARConfigBuilder13Test
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.3.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDTest.java Thu Jun 24 18:06:24 2010
@@ -33,10 +33,10 @@ public class EARConfigBuilder14AltDDTest
         super.setUp();
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDUnpackedTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDUnpackedTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDUnpackedTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14AltDDUnpackedTest.java Thu Jun 24 18:06:24 2010
@@ -33,10 +33,10 @@ public class EARConfigBuilder14AltDDUnpa
         super.setUp();
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4-unpacked.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedTest.java Thu Jun 24 18:06:24 2010
@@ -34,10 +34,10 @@ public class EARConfigBuilder14NakedTest
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4-naked.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "test-ejb-jar.jar", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "test-war.war", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "test-rar.rar", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedUnpackedTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedUnpackedTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedUnpackedTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14NakedUnpackedTest.java Thu Jun 24 18:06:24 2010
@@ -34,10 +34,10 @@ public class EARConfigBuilder14NakedUnpa
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4-naked-unpacked.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14Test.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14Test.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14Test.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14Test.java Thu Jun 24 18:06:24 2010
@@ -34,10 +34,10 @@ public class EARConfigBuilder14Test
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14UnpackedTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14UnpackedTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14UnpackedTest.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder14UnpackedTest.java Thu Jun 24 18:06:24 2010
@@ -34,10 +34,10 @@ public class EARConfigBuilder14UnpackedT
 
         earFile = JarUtils.createJarFile(resolveFile("target/test-ear-j2ee_1.4-unpacked.ear"));
         locations.put(null, new Artifact("org.apache.geronimo.testsupport", "test-ear-javaee_5", "3.0-SNAPSHOT", "ear"));
-        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, null, jndiContext, parentModule);
+        ejbConfigBuilder.ejbModule = new EJBModule(false, ejbModuleName, null, null, null, "ejb.jar/", null, null, null, jndiContext, parentModule);
         webConfigBuilder.contextRoot = contextRoot;
-        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, null, jndiContext, parentModule);
-        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, null, jndiContext, parentModule);
+        webConfigBuilder.webModule = new WebModule(false, webModuleName, null, null, (JarFile)null, "war.war/", null, null, null, contextRoot, WEB_NAMESPACE, jndiContext, parentModule);
+        connectorConfigBuilder.connectorModule = new ConnectorModule(false, raModuleName, null, null, null, "rar.rar/", null, null, null, jndiContext, parentModule);
     }
 
     protected void tearDown() throws Exception {
--- geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/WebServiceRefAnnotationHelper.java (original)
+++ geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/main/java/org/apache/geronimo/j2ee/deployment/annotation/WebServiceRefAnnotationHelper.java Thu Jun 24 18:06:24 2010
@@ -21,6 +21,7 @@ import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collection;
 import java.util.List;
 
 import javax.jws.HandlerChain;
@@ -28,11 +29,8 @@ import javax.xml.ws.WebServiceClient;
 import javax.xml.ws.WebServiceRef;
 import javax.xml.ws.WebServiceRefs;
 import org.apache.geronimo.common.DeploymentException;
-import org.apache.geronimo.xbeans.javaee6.FullyQualifiedClassType;
-import org.apache.geronimo.xbeans.javaee6.JndiNameType;
-import org.apache.geronimo.xbeans.javaee6.ServiceRefType;
-import org.apache.geronimo.xbeans.javaee6.XsdAnyURIType;
-import org.apache.geronimo.xbeans.javaee6.XsdStringType;
+import org.apache.openejb.jee.JndiConsumer;
+import org.apache.openejb.jee.ServiceRef;
 import org.apache.xbean.finder.AbstractFinder;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -76,17 +74,17 @@ public final class WebServiceRefAnnotati
     /**
      * Update the deployment descriptor from the WebServiceRef and WebServiceRefs annotations
      *
      * @param annotatedApp Access to the spec dd
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    public static void processAnnotations(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
-        if (annotatedApp != null) {
+    public static void processAnnotations(JndiConsumer specDD, AbstractFinder classFinder) throws DeploymentException {
+        if (specDD != null) {
             if (classFinder.isAnnotationPresent(WebServiceRefs.class)) {
-                processWebServiceRefs(annotatedApp, classFinder);
+                processWebServiceRefs(specDD, classFinder);
             }
             if (classFinder.isAnnotationPresent(WebServiceRef.class)) {
-                processWebServiceRef(annotatedApp, classFinder);
+                processWebServiceRef(specDD, classFinder);
             }
         }
     }
@@ -99,7 +97,7 @@ public final class WebServiceRefAnnotati
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processWebServiceRef(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processWebServiceRef(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processWebServiceRef(): Entry: AnnotatedApp: " + annotatedApp.toString());
 
         List<Class> classeswithWebServiceRef = classFinder.findAnnotatedClasses(WebServiceRef.class);
@@ -131,7 +129,7 @@ public final class WebServiceRefAnnotati
         }
 
         // Validate deployment descriptor to ensure it's still okay
-        validateDD(annotatedApp);
+//        validateDD(annotatedApp);
 
         log.debug("processWebServiceRef(): Exit: AnnotatedApp: " + annotatedApp.toString());
     }
@@ -144,7 +142,7 @@ public final class WebServiceRefAnnotati
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error
      */
-    private static void processWebServiceRefs(AnnotatedApp annotatedApp, AbstractFinder classFinder) throws DeploymentException {
+    private static void processWebServiceRefs(JndiConsumer annotatedApp, AbstractFinder classFinder) throws DeploymentException {
         log.debug("processWebServiceRefs(): Entry");
 
         List<Class> classeswithWebServiceRefs = classFinder.findAnnotatedClasses(WebServiceRefs.class);
@@ -187,7 +185,7 @@ public final class WebServiceRefAnnotati
      * @param field      Field name with the @WebServiceRef annoation
      * @param annotatedApp  Access to the specc dd
      */
-    private static void addWebServiceRef(AnnotatedApp annotatedApp, WebServiceRef annotation, Class cls, Method method, Field field) {
+    private static void addWebServiceRef(JndiConsumer annotatedApp, WebServiceRef annotation, Class cls, Method method, Field field) {
         log.debug("addWebServiceRef( [annotatedApp] " + annotatedApp.toString() + "," + '\n' +
                 "[annotation] " + annotation.toString() + "," + '\n' +
                 "[cls] " + (cls != null ? cls.getName() : null) + "," + '\n' +
@@ -243,11 +241,11 @@ public final class WebServiceRefAnnotati
         // 1. <service-ref>
         //------------------------------------------------------------------------------------------
 
-        ServiceRefType serviceRef = null;
+        ServiceRef serviceRef = null;
 
-        ServiceRefType[] serviceRefs = annotatedApp.getServiceRefArray();
-        for (ServiceRefType currServiceRef : serviceRefs) {
-            if (currServiceRef.getServiceRefName().getStringValue().trim().equals(webServiceRefName)) {
+        Collection<ServiceRef> serviceRefs = annotatedApp.getServiceRef();
+        for (ServiceRef currServiceRef : serviceRefs) {
+            if (currServiceRef.getServiceRefName().trim().equals(webServiceRefName)) {
                 serviceRef = currServiceRef;
                 break;
             }
@@ -255,27 +253,22 @@ public final class WebServiceRefAnnotati
 
         if (serviceRef == null) {
             // Doesn't exist in deployment descriptor -- add new
-            serviceRef = annotatedApp.addNewServiceRef();
+            serviceRef = new ServiceRef();
 
             // ------------------------------------------------------------------------------
             // <service-ref> required elements:
             // ------------------------------------------------------------------------------
 
             // service-ref-name
-            JndiNameType serviceRefName = serviceRef.addNewServiceRefName();
-            serviceRefName.setStringValue(webServiceRefName);
-            serviceRef.setServiceRefName(serviceRefName);
+            serviceRef.setServiceRefName(webServiceRefName);
 
             // service-ref-interface
             if (!webServiceRefValue.equals(Object.class)) {
-                FullyQualifiedClassType qualifiedClass = serviceRef.addNewServiceInterface();
-                qualifiedClass.setStringValue(webServiceRefValue.getName());
-                serviceRef.setServiceInterface(qualifiedClass);
+                serviceRef.setServiceInterface(webServiceRefValue.getName());
             } else {
-                FullyQualifiedClassType qualifiedClass = serviceRef.addNewServiceInterface();
-                qualifiedClass.setStringValue(webServiceRefType.getName());
-                serviceRef.setServiceInterface(qualifiedClass);
+                serviceRef.setServiceInterface(webServiceRefType.getName());
             }
+            annotatedApp.getServiceRef().add(serviceRef);
         }
 
         //------------------------------------------------------------------------------
@@ -283,21 +276,17 @@ public final class WebServiceRefAnnotati
         //------------------------------------------------------------------------------
 
         // service-ref-type
-        if (!serviceRef.isSetServiceRefType() && !webServiceRefType.equals(Object.class)) {
-            FullyQualifiedClassType qualifiedClass = serviceRef.addNewServiceRefType();
-            qualifiedClass.setStringValue(webServiceRefType.getName());
-            serviceRef.setServiceRefType(qualifiedClass);
+        if (serviceRef.getServiceRefType() == null && !webServiceRefType.equals(Object.class)) {
+            serviceRef.setServiceRefType(webServiceRefType.getName());
         }
 
         // mapped-name
-        if (!serviceRef.isSetMappedName() && annotation.mappedName().trim().length() > 0) {
-            XsdStringType mappedName = serviceRef.addNewMappedName();
-            mappedName.setStringValue(annotation.mappedName().trim());
-            serviceRef.setMappedName(mappedName);
+        if (serviceRef.getMappedName() == null && annotation.mappedName().trim().length() > 0) {
+            serviceRef.setMappedName(annotation.mappedName().trim());
         }
 
         // WSDL document location
-        if (!serviceRef.isSetWsdlFile()) {
+        if (serviceRef.getWsdlFile() == null) {
             String wsdlLocation = annotation.wsdlLocation();
 
             if (wsdlLocation == null || wsdlLocation.trim().length() == 0) {
@@ -315,14 +304,12 @@ public final class WebServiceRefAnnotati
             }
 
             if (wsdlLocation != null && wsdlLocation.trim().length() > 0) {
-                XsdAnyURIType wsdlFile = serviceRef.addNewWsdlFile();
-                wsdlFile.setStringValue(wsdlLocation);
-                serviceRef.setWsdlFile(wsdlFile);
+                serviceRef.setWsdlFile(wsdlLocation);
             }
         }
 
         // handler-chains
-        if (!serviceRef.isSetHandlerChains()) {
+        if (serviceRef.getHandlerChains() == null) {
             HandlerChain handlerChain = null;
             Class annotatedClass = null;
             if (method != null) {
@@ -350,7 +337,7 @@ public final class WebServiceRefAnnotati
         }
         
         if (method != null || field != null) {
-            configureInjectionTarget(serviceRef.addNewInjectionTarget(), method, field);
+            serviceRef.getInjectionTarget().add(configureInjectionTarget(method, field));
         }
 
     }
@@ -76,17 +74,17 @@ public final class WebServiceRefAnnotati
      * Update the deployment descriptor from the WebServiceRef and WebServiceRefs annotations
      *
-     * @param annotatedApp Access to the spec dd
+     * @param specDD Access to the spec dd
      * @param classFinder Access to the classes of interest
      * @throws DeploymentException if parsing or validation error

Modified: geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13NakedTest.java
URL: http://svn.apache.org/viewvc/geronimo/server/trunk/plugins/j2ee/geronimo-j2ee-builder/src/test/java/org/apache/geronimo/j2ee/deployment/EARConfigBuilder13NakedTest.java?rev=957655&r1=957654&r2=957655&view=diff
==============================================================================